@@ -6,7 +6,7 @@
 class Help {
 
 public:
-    static void showHelp(std::string_view option);
+    static void showHelp(const std::string& option);
 
 };
 
