@@ -46,7 +46,8 @@ int main(int argc, char *argv[]) {
         connectionModel,
         connectionRoleInstruction,
         connectionDetailedInstructions,
-        connectionContent
+        connectionContent,
+        maxOutputTokens
         ] = Options::getOptions(argc, argVector);
 
     if (connectionKey.empty() || connectionModel.empty() || connectionContent.empty()) {
@@ -54,7 +55,7 @@ int main(int argc, char *argv[]) {
         return 0;
     }
 
-    std::cout << "An API connection is started. Please wait for the AI's reply." << std::endl;
+    std::cout << "An API connection is started. Please wait for the AI's reply.\n";
 
     auto reply = Net::aiDispatcher(
         connectionProvider,
@@ -62,7 +63,10 @@ int main(int argc, char *argv[]) {
         connectionModel,
         connectionRoleInstruction,
         connectionDetailedInstructions,
-        connectionContent);
+        connectionContent,
+        maxOutputTokens);
+
+    std::cout << "\n";
 
     if (reply.has_value()) {
         std::cout << reply.value() << std::endl;
