@@ -143,6 +143,26 @@ std::string Options::selectRole(
     return selectedRole;
 }
 
+int Options::setMaxOutputTokens() {
+    int maxOutputTokens = 0;
+
+    std::cout << "Please set the number of max output tokens.\n"
+                 "If the number exceeds the AI model's limit,\n"
+                 "the connection will fail.\n"
+                 "For keep the default value (4096),\n"
+                 "please input 0 and press the Enter key.\n";
+
+    int number;
+    std::cin >> number;
+    std::cin.ignore();
+
+    if (number > 0) {
+        maxOutputTokens = number;
+    }
+
+    return maxOutputTokens;
+}
+
 std::string Options::receiveMultiLines() {
     std::cout << "Note: You may input multiple lines and use the Enter key to start a new line.\n"
                  "      Restricted by a terminal's mechanism for handling some keys like\n"
@@ -166,7 +186,7 @@ std::string Options::receiveMultiLines() {
     return inputtedText;
 }
 
-std::array<std::string, 6> Options::getOptions(int argc, const std::vector<std::string>& argVector) {
+std::array<std::string, 7> Options::getOptions(int argc, const std::vector<std::string>& argVector) {
     // All available options.
     std::vector<std::string> options = {
         "--add-key",  // Add or update an API key.
@@ -181,7 +201,8 @@ std::array<std::string, 6> Options::getOptions(int argc, const std::vector<std::
         "--remove-role",
         "-model",  // Specify an AI model.
         "-role",  // Specify a preset role for AI, or give a role instruction to AI.
-        "-content"  // Give detailed instructions to AI.
+        "-content",  // Give detailed instructions to AI.
+        "-tokens" // Set max output tokens.
     };
 
     std::string connectionProvider;
@@ -190,6 +211,8 @@ std::array<std::string, 6> Options::getOptions(int argc, const std::vector<std::
     std::string connectionRoleInstruction;
     std::string connectionDetailedInstructions;
     std::string connectionContent;
+    int maxOutputTokens = 4096;
+    bool needToSetMaxOutputTokens = false;
 
     std::vector<std::string> inputtedArguments;
 
@@ -587,6 +610,30 @@ std::array<std::string, 6> Options::getOptions(int argc, const std::vector<std::
 
             connectionContent = Config::cleanString(optionValue);
         }
+
+        else if (option == "-tokens") {
+            if (optionValue.empty()) {
+                needToSetMaxOutputTokens = true;
+            } else {
+                auto getDigitsFromString = [](const std::string& optionValue) {
+                    std::string digitString = optionValue
+                    | std::views::filter([](unsigned char c) { return std::isdigit(c); })
+                    | std::ranges::to<std::string>();
+
+                    if (!digitString.empty()) {
+                        return std::stoi(digitString);
+                    }
+
+                    return 0;
+                };
+
+                auto inputtedMaxOutputTokens = getDigitsFromString(optionValue);
+
+                if (inputtedMaxOutputTokens > 0) {
+                    maxOutputTokens = inputtedMaxOutputTokens;
+                }
+            }
+        }
     }
 
     auto keys = std::get<0>(Config::loadConf("read"));
@@ -597,6 +644,17 @@ std::array<std::string, 6> Options::getOptions(int argc, const std::vector<std::
                 connectionKey = key;
             }
         }
+
+        if (needToSetMaxOutputTokens && connectionProvider == "Claude") {
+            int inputtedMaxOutputTokens = setMaxOutputTokens();
+
+            if (inputtedMaxOutputTokens > 0) {
+                maxOutputTokens = inputtedMaxOutputTokens;
+                std::cout << "The number of max output tokens is set to " << maxOutputTokens << ".\n\n";
+            } else {
+                std::cout << "The number of max output tokens is " << maxOutputTokens << ".\n\n";
+            }
+        }
     }
 
     return std::array{
@@ -605,6 +663,7 @@ std::array<std::string, 6> Options::getOptions(int argc, const std::vector<std::
         connectionModel,
         connectionRoleInstruction,
         connectionDetailedInstructions,
-        connectionContent
+        connectionContent,
+        std::to_string(maxOutputTokens)
     };
 }
\ No newline at end of file
